@@ -28,7 +28,9 @@ class AssetsController(HTTPMethodView):
             task = await self.__jobs.find_by_value(uid, token, t_asset)
             if task:
                 file_filepath = task.get("path")
+                file_name = os.path.basename(file_filepath)
                 params = task.get("params", dict())
+                inline = params.get("inline", False)
                 self.__logger.info(
                     {
                         "id": uid,
@@ -42,7 +44,10 @@ class AssetsController(HTTPMethodView):
                     await self.__jobs.update(
                         uid, file_filepath, t_asset, token, params, t_health, 1
                     )
-                    res = await response.file(file_filepath)
+                    res = await response.file(
+                        location=file_filepath,
+                        filename=(file_name if not inline else None),
+                    )
                     self.__logger.info(
                         {
                             "id": uid,
