@@ -1,6 +1,6 @@
 from sanic.views import HTTPMethodView
 from sanic.response import json
-from naas.types import t_health, t_static
+from naas.types import t_health, t_asset
 import uuid
 
 
@@ -24,13 +24,13 @@ class EnvController(HTTPMethodView):
         uid = str(uuid.uuid4())
         env = {
             "status": t_health,
-            "notif_url": self.__notif_url,
+            "NOTIFICATIONS_API": self.__notif_url,
             "JUPYTERHUB_USER": self.__user,
             "JUPYTERHUB_URL": self.__public_url,
             "PUBLIC_PROXY_API": self.__proxy_url,
             "TZ": self.__tz,
         }
         self.__logger.info(
-            {"id": uid, "type": t_static, "status": "send", "filepath": "env"}
+            {"id": uid, "type": t_asset, "status": "send", "filepath": "env"}
         )
         return json(env)
